@@ -62,6 +62,8 @@ from vtkmodules.vtkIOVideo import *
 from vtkmodules.vtkIOFFMPEG import *
 from vtkmodules.vtkRenderingFFMPEGOpenGL2 import *
 from vtkmodules.vtkRenderingExternal import *
+from vtkmodules.vtkFiltersCellGrid import *
+from vtkmodules.vtkRenderingCellGrid import *
 from vtkmodules.vtkParallelMPI4Py import *
 from vtkmodules.vtkIOXdmf2 import *
 from vtkmodules.vtkIOVeraOut import *
@@ -87,6 +89,7 @@ from vtkmodules.vtkIOOpenVDB import *
 from vtkmodules.vtkIOOggTheora import *
 from vtkmodules.vtkIOOMF import *
 from vtkmodules.vtkIOODBC import *
+from vtkmodules.vtkIOOCCT import *
 from vtkmodules.vtkIOMySQL import *
 from vtkmodules.vtkIOMotionFX import *
 from vtkmodules.vtkIOGeometry import *
@@ -102,6 +105,7 @@ from vtkmodules.vtkIOH5part import *
 from vtkmodules.vtkIOH5Rage import *
 from vtkmodules.vtkIOGeoJSON import *
 from vtkmodules.vtkIOFides import *
+from vtkmodules.vtkIOFLUENTCFF import *
 from vtkmodules.vtkIOExportPDF import *
 from vtkmodules.vtkRenderingGL2PSOpenGL2 import *
 from vtkmodules.vtkIOExportGL2PS import *
@@ -109,6 +113,7 @@ from vtkmodules.vtkIOEnSight import *
 from vtkmodules.vtkIOCityGML import *
 from vtkmodules.vtkIOChemistry import *
 from vtkmodules.vtkIOCesium3DTiles import *
+from vtkmodules.vtkIOCellGrid import *
 from vtkmodules.vtkIOCONVERGECFD import *
 from vtkmodules.vtkIOHDF import *
 from vtkmodules.vtkIOCGNSReader import *
@@ -133,9 +138,11 @@ from vtkmodules.vtkRenderingAnnotation import *
 from vtkmodules.vtkImagingHybrid import *
 from vtkmodules.vtkImagingColor import *
 from vtkmodules.vtkFiltersTopology import *
+from vtkmodules.vtkFiltersTensor import *
 from vtkmodules.vtkFiltersSelection import *
 from vtkmodules.vtkFiltersSMP import *
 from vtkmodules.vtkFiltersReebGraph import *
+from vtkmodules.vtkFiltersReduction import *
 from vtkmodules.vtkFiltersPython import *
 from vtkmodules.vtkFiltersProgrammable import *
 from vtkmodules.vtkFiltersModeling import *
@@ -148,6 +155,7 @@ from vtkmodules.vtkFiltersImaging import *
 from vtkmodules.vtkFiltersExtraction import *
 from vtkmodules.vtkFiltersGeometry import *
 from vtkmodules.vtkFiltersHybrid import *
+from vtkmodules.vtkFiltersHyperTree import *
 from vtkmodules.vtkFiltersTexture import *
 from vtkmodules.vtkFiltersParallel import *
 from vtkmodules.vtkFiltersParallelImaging import *
@@ -155,12 +163,12 @@ from vtkmodules.vtkFiltersParallelGeometry import *
 from vtkmodules.vtkFiltersFlowPaths import *
 from vtkmodules.vtkFiltersParallelFlowPaths import *
 from vtkmodules.vtkFiltersParallelDIY2 import *
+from vtkmodules.vtkFiltersGeometryPreview import *
 from vtkmodules.vtkFiltersGeneric import *
 from vtkmodules.vtkFiltersAMR import *
 from vtkmodules.vtkDomainsParallelChemistry import *
 from vtkmodules.vtkFiltersParallelMPI import *
 from vtkmodules.vtkDomainsChemistryOpenGL2 import *
-from vtkmodules.vtkFiltersHyperTree import *
 from vtkmodules.vtkCommonPython import *
 from vtkmodules.vtkCommonArchive import *
 from vtkmodules.vtkChartsCore import *
