@@ -7,7 +7,7 @@ import sys
 
 def _windows_dll_path():
     import os
-    _vtk_python_path = 'lib/python3.11/site-packages/vtkmodules'
+    _vtk_python_path = 'lib/python3.12/site-packages/vtkmodules'
     _vtk_dll_path = 'bin'
     # Compute the DLL path based on the location of the file and traversing up
     # the installation prefix to append the DLL path.
@@ -119,6 +119,8 @@ __all__ = [
     'vtkIOFFMPEG',
     'vtkRenderingFFMPEGOpenGL2',
     'vtkRenderingExternal',
+    'vtkFiltersCellGrid',
+    'vtkRenderingCellGrid',
     'vtkParallelMPI4Py',
     'vtkIOXdmf2',
     'vtkIOVeraOut',
@@ -144,6 +146,7 @@ __all__ = [
     'vtkIOOggTheora',
     'vtkIOOMF',
     'vtkIOODBC',
+    'vtkIOOCCT',
     'vtkIOMySQL',
     'vtkIOMotionFX',
     'vtkIOGeometry',
@@ -159,6 +162,7 @@ __all__ = [
     'vtkIOH5Rage',
     'vtkIOGeoJSON',
     'vtkIOFides',
+    'vtkIOFLUENTCFF',
     'vtkIOExportPDF',
     'vtkRenderingGL2PSOpenGL2',
     'vtkIOExportGL2PS',
@@ -166,6 +170,7 @@ __all__ = [
     'vtkIOCityGML',
     'vtkIOChemistry',
     'vtkIOCesium3DTiles',
+    'vtkIOCellGrid',
     'vtkIOCONVERGECFD',
     'vtkIOHDF',
     'vtkIOCGNSReader',
@@ -190,9 +195,11 @@ __all__ = [
     'vtkImagingHybrid',
     'vtkImagingColor',
     'vtkFiltersTopology',
+    'vtkFiltersTensor',
     'vtkFiltersSelection',
     'vtkFiltersSMP',
     'vtkFiltersReebGraph',
+    'vtkFiltersReduction',
     'vtkFiltersPython',
     'vtkFiltersProgrammable',
     'vtkFiltersModeling',
@@ -205,6 +212,7 @@ __all__ = [
     'vtkFiltersExtraction',
     'vtkFiltersGeometry',
     'vtkFiltersHybrid',
+    'vtkFiltersHyperTree',
     'vtkFiltersTexture',
     'vtkFiltersParallel',
     'vtkFiltersParallelImaging',
@@ -212,12 +220,12 @@ __all__ = [
     'vtkFiltersFlowPaths',
     'vtkFiltersParallelFlowPaths',
     'vtkFiltersParallelDIY2',
+    'vtkFiltersGeometryPreview',
     'vtkFiltersGeneric',
     'vtkFiltersAMR',
     'vtkDomainsParallelChemistry',
     'vtkFiltersParallelMPI',
     'vtkDomainsChemistryOpenGL2',
-    'vtkFiltersHyperTree',
     'vtkCommonPython',
     'vtkCommonArchive',
     'vtkChartsCore',
@@ -236,4 +244,4 @@ __all__ = [
 
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.2.6"
+__version__ = "9.3.0"
